@@ -57,6 +57,37 @@ from aasrp.utils import LoggerAddTag, get_main_character_from_user
 logger = LoggerAddTag(get_extension_logger(__name__), __title__)
 
 
+def _attempt_to_re_add_ship_information_to_request(
+    srp_request: AaSrpRequest,
+) -> AaSrpRequest:
+    """
+    If for some reason the ship gets removed from EveType table,
+    srp_request.ship is None. In this case, we have to re-add the ship to prevent
+    errors in our DataTables ...
+    :param srp_request:
+    :return:
+    """
+
+    srp_kill_link = AaSrpManager.get_kill_id(srp_request.killboard_link)
+
+    (
+        ship_type_id,
+        ship_value,
+        victim_id,
+    ) = AaSrpManager.get_kill_data(srp_kill_link)
+
+    (
+        srp_request__ship,
+        created_from_esi,
+    ) = EveType.objects.get_or_create_esi(id=ship_type_id)
+
+    srp_request.ship_name = srp_request__ship.name
+    srp_request.ship = srp_request__ship
+    srp_request.save()
+
+    return srp_request
+
+
 @login_required
 @permission_required("aasrp.basic_access")
 def dashboard(request: WSGIRequest, show_all_links: bool = False) -> HttpResponse:
@@ -192,25 +223,44 @@ def ajax_dashboard_user_srp_requests_data(request: WSGIRequest) -> JsonResponse:
 
     data = list()
 
-    requests = AaSrpRequest.objects.filter(creator=request.user).prefetch_related(
-        "creator",
-        "creator__profile__main_character",
-        "character",
-        "srp_link",
-        "srp_link__creator",
-        "srp_link__creator__profile__main_character",
-        "ship",
+    requests = (
+        AaSrpRequest.objects.filter(creator=request.user)
+        # .filter(ship__isnull=False)
+        .prefetch_related(
+            "creator",
+            "creator__profile__main_character",
+            "character",
+            "srp_link",
+            "srp_link__creator",
+            "srp_link__creator__profile__main_character",
+            "ship",
+        )
     )
 
     for srp_request in requests:
         killboard_link = ""
+
         if srp_request.killboard_link:
-            ship_render_icon_html = get_type_render_url_from_type_id(
-                evetype_id=srp_request.ship.id,
-                evetype_name=srp_request.ship.name,
-                size=32,
-                as_html=True,
-            )
+            try:
+                ship_render_icon_html = get_type_render_url_from_type_id(
+                    evetype_id=srp_request.ship.id,
+                    evetype_name=srp_request.ship.name,
+                    size=32,
+                    as_html=True,
+                )
+            except AttributeError:
+                # For some reason it seems the ship has been removed from EveType
+                # table, attempt to add it again ...
+                srp_request = _attempt_to_re_add_ship_information_to_request(
+                    srp_request
+                )
+
+                ship_render_icon_html = get_type_render_url_from_type_id(
+                    evetype_id=srp_request.ship.id,
+                    evetype_name=srp_request.ship.name,
+                    size=32,
+                    as_html=True,
+                )
 
             killboard_link = (
                 '<a href="{zkb_link}" target="_blank">'
@@ -247,7 +297,10 @@ def ajax_dashboard_user_srp_requests_data(request: WSGIRequest) -> JsonResponse:
                 "fleet_name": srp_request.srp_link.srp_name,
                 "srp_code": srp_request.srp_link.srp_code,
                 "request_code": srp_request.request_code,
-                "ship_html": {"display": killboard_link, "sort": srp_request.ship.name},
+                "ship_html": {
+                    "display": killboard_link,
+                    "sort": srp_request.ship.name,
+                },
                 "ship": srp_request.ship.name,
                 "zkb_link": killboard_link,
                 "zbk_loss_amount": srp_request.loss_amount,
@@ -433,7 +486,7 @@ def request_srp(request: WSGIRequest, srp_code: str) -> HttpResponse:
             srp_request.creator = creator
             srp_request.srp_link = srp_link
 
-            # parse zkillboard killmail
+            # parse killmail
             try:
                 srp_kill_link = AaSrpManager.get_kill_id(srp_request.killboard_link)
 
@@ -676,12 +729,26 @@ def ajax_srp_link_view_requests_data(
     for srp_request in srp_requests:
         killboard_link = ""
         if srp_request.killboard_link:
-            ship_render_icon_html = get_type_render_url_from_type_id(
-                evetype_id=srp_request.ship.id,
-                evetype_name=srp_request.ship.name,
-                size=32,
-                as_html=True,
-            )
+            try:
+                ship_render_icon_html = get_type_render_url_from_type_id(
+                    evetype_id=srp_request.ship.id,
+                    evetype_name=srp_request.ship.name,
+                    size=32,
+                    as_html=True,
+                )
+            except AttributeError:
+                # For some reason it seems the ship has been removed from EveType
+                # table, attempt to add it again ...
+                srp_request = _attempt_to_re_add_ship_information_to_request(
+                    srp_request
+                )
+
+                ship_render_icon_html = get_type_render_url_from_type_id(
+                    evetype_id=srp_request.ship.id,
+                    evetype_name=srp_request.ship.name,
+                    size=32,
+                    as_html=True,
+                )
 
             killboard_link = (
                 f'<a href="{srp_request.killboard_link}" target="_blank">'
@@ -876,12 +943,24 @@ def ajax_srp_request_additional_information(
 
     killboard_link = ""
     if srp_request.killboard_link:
-        ship_render_icon_html = get_type_render_url_from_type_id(
-            evetype_id=srp_request.ship.id,
-            evetype_name=srp_request.ship.name,
-            size=32,
-            as_html=True,
-        )
+        try:
+            ship_render_icon_html = get_type_render_url_from_type_id(
+                evetype_id=srp_request.ship.id,
+                evetype_name=srp_request.ship.name,
+                size=32,
+                as_html=True,
+            )
+        except AttributeError:
+            # For some reason it seems the ship has been removed from EveType
+            # table, attempt to add it again ...
+            srp_request = _attempt_to_re_add_ship_information_to_request(srp_request)
+
+            ship_render_icon_html = get_type_render_url_from_type_id(
+                evetype_id=srp_request.ship.id,
+                evetype_name=srp_request.ship.name,
+                size=32,
+                as_html=True,
+            )
 
         killboard_link = (
             f"{ship_render_icon_html}"
